
# Dataclasses as function parameters

## Basic version

!!! Example "Basic use of classes as parameters"
    === "Help"
        ```txt 
        --8<-- 'examples/dataclasses/basic.out'
        ```
    
    === "Code"
        ```python 
        --8<-- 'examples/dataclasses/basic.py'
        ```


## As arguments

!!! Example "All options as arguments"
    === "Help"
        ```txt 
        --8<-- 'examples/dataclasses/with_arguments.out'
        ```
    === "Code"
        ```python 
        --8<-- 'examples/dataclasses/with_arguments.py'
        ```

## With custom converter

!!! Example "Using custom converter"
    === "Help"
        ```txt 
        --8<-- 'examples/dataclasses/custom_converter.out'
        ```
    === "Code"

        ```python 
        --8<-- 'examples/dataclasses/custom_converter.py'
        ```

